/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#include "calculatePolar.h"

#include <moduleBasics/strategySelector.h>
#include <moduleBasics/module.h>

#include <string>
#include <vector>
#include <memory>
#include <filesystem>
#include <map>
#include <iostream>

#include "taw/tawCalculatePolar.h"
#include "laminarTAW/laminarTAWCalculatePolar.h"
#include "bwb/bwbCalculatePolar.h"

using std::endl;

calculatePolar::calculatePolar(const int argc, char *argv[], const std::string &toolName, const std::string &toolVersion)
    : Module(argc, argv, toolName, toolVersion) {
    // at the moment calculatePolar only offers the TAW route
    std::string configuration = rtIO_->aircraft_configuration_type();
    std::string aeroTechnologies = rtIO_->aerodynamic_technologies();
    route = {configuration, aeroTechnologies};
    strategy.setStrategy(routing(route)(rtIO_));
}

strategyaccess calculatePolar::routing(const std::vector<std::string> &route) {
    // Routing table with two cases
    std::map<std::string, std::map<std::string, strategyaccess>> table = {
        {"tube_and_wing",
            std::map<std::string, strategyaccess>{
                {"false", [](const std::shared_ptr<RuntimeIO>& arg) { return std::make_unique<tawCalculatePolar>(arg); }},
                {"true", [](const std::shared_ptr<RuntimeIO>& arg) { return std::make_unique<laminarTAWCalculatePolar>(arg); }},
            }
        },
        {"blended_wing_body",
            std::map<std::string, strategyaccess>{
                {"false", [](const std::shared_ptr<RuntimeIO>& arg) { return std::make_unique<bwbCalculatePolar>(arg); }},
            }
        }
    };
    return table[route.at(0)][route.at(1)];
}