/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#include "tawCalculatePolar.h"
#include "tawDefaultStrategy.h"
#include "tawCalculatePolarConfig.h"

#include <moduleBasics/strategySelector.h>
#include <moduleBasics/report.h>
#include <moduleBasics/plot.h>
#include <aixml/node.h>

#include <algorithm>
#include <memory>
#include <exception>
#include <iomanip>
#include <string>
#include <vector>
#include <utility>  // make_pair

#ifdef _WIN32
    #include <fileapi.h>
    #include <windows.h>
#endif  // _WIN32

using std::endl;
using std::exception;
using std::fixed;
using std::ofstream;
using std::setprecision;
using std::string;
using std::stringstream;
using std::vector;

void tawCalculatePolar::initialize() {
    myRuntimeInfo->out << "Calculate Polar for TAW: Initialize..." << endl;
    config_ = std::make_shared<tawCalculatePolarConfig>(rtIO_->moduleConfig);
    myDefaultStrategy = std::make_shared<tawDefaultStrategy>(rtIO_, config_);
    this->selectAeroStrategy();
}

void tawCalculatePolar::run() {
    myRuntimeInfo->out << "Calculate Polar for TAW: Run..." << endl;
    std::string strategy = "defaultStrategy";
    if (strategy == "defaultStrategy") {
        myDefaultStrategy->run();
    }
}

void tawCalculatePolar::update() {
    myRuntimeInfo->out << "Calculate Polar for TAW: Update..." << endl;
    if (config_->execution_mode.value() == "mode_0") {
        myDefaultStrategy->writePolarXML();
        myDefaultStrategy->setOutputValues();
        myDefaultStrategy->setReferenceValues();
    } else if (config_->execution_mode.value() == "mode_1") {
        myDefaultStrategy->setReferenceValues();
    } else {
        myRuntimeInfo->err << "execution_mode: " << config_->execution_mode.value() << " in config file program_settings/execution_mode is not supported! " << endl;
    }
    myDefaultStrategy->update_xml_entries(config_->execution_mode.value());
}

void tawCalculatePolar::report() {
    myRuntimeInfo->out << "Calculate Polar for TAW: Report..." << endl;
    if (rtIO_->plotOn) {
        myRuntimeInfo->out << "    - Calculate Polar for TAW: Write Polar Data..." << endl;
        myDefaultStrategy->writePolarData();
        myDefaultStrategy->writeViscDragData();
    }
    if (rtIO_->reportOn) {
        myRuntimeInfo->out << "    - Calculate Polar for TAW: Create HTML Report Body ..." << endl;
        set_html_body();
    }
    report_.generateReports();
}

void tawCalculatePolar::save() {
    myRuntimeInfo->out << "Calculate Polar for TAW: Save..." << endl;
}

void tawCalculatePolar::selectAeroStrategy() {
}
