/* UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#ifndef ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_EMISSION_CALCULATION_MISSION_EMISSIONS_MISSIONCONFIG_H_
#define ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_EMISSION_CALCULATION_MISSION_EMISSIONS_MISSIONCONFIG_H_

#include <string>
#include <unordered_map>
#include <utility>
#include <vector>
#include <array>
#include <aixml/endnode.h>
#include "../../emissionsClass.h"

/** \class MissionConfig
 * \brief Class for the config settings needed for mission calculation
*/
class MissionConfig {
 public:
    std::string kerosene_method_HC;/**<HC Emission index calculation method for kerosene; DLR Omega: mode_0, BFM2: mode_1, ICAO Emission indices: mode_2 */
    std::string kersosene_method_CO;/**<CO Emission index calculation method for kerosene; DLR Omega: mode_0, BFM2: mode_1, ICAO Emission indices: mode_2 */
    std::string kerosene_method_NOx;/**<NOx Emission index calculation method for kerosene; P3T3: mode_0, BFM2: mode_1, GasTurb: mode_2 */
    std::string kerosene_method_soot;/**<soot Emission index calculation method for kerosene; DLR correlation: mode_0, Whyte: mode_1, constant: mode_2 */
    std::string hydrogen_method_NOx; /**<NOx Emission index calculation method for hydrogen; P3T3: mode_0*/
    double relative_humidity;/**< Relative humidity of air [-] */

    /** \brief Default constructor of class missionConfig
     */
    MissionConfig();


    /** \brief Destructor of class missionConfig
     */
    virtual ~MissionConfig();

    /** \brief Function to read mission specific data from ecological_assessment_config.xml
     * \param config Node of the data structure defined by config file
     */
    void read_all_config_data(const node& config);
};

#endif // ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_EMISSION_CALCULATION_MISSION_EMISSIONS_MISSIONCONFIG_H_
