/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#include "conventionalEmpennageDesignConfig.h"

namespace taw {
namespace low {

ConventionalConfig::ConventionalConfig()
    : design_mode(EndnodeReadOnly<std::string>("module_configuration_file/program_settings/modes/design_mode")),
      mass_mode(EndnodeReadOnly<std::string>("module_configuration_file/program_settings/modes/mass_mode/method")),
      mass_mode_flops_technology_factor(EndnodeReadOnly<double>("module_configuration_file/program_settings/modes/mass_mode/parameters/mode_0/technology_factor")),
      vertical_stabilizer(TailElement(
          "module_configuration_file/program_settings/tube_and_wing/low_fidelity/conventional/tail_element@0/")),
      horizontal_stabilizer(TailElement(
          "module_configuration_file/program_settings/tube_and_wing/low_fidelity/conventional/tail_element@1/")),
      common_airfoil_data_path(EndnodeReadOnly<std::string>("module_configuration_file/program_settings/common_airfoil_data_path")) {}

void ConventionalConfig::read(const node& xml) {
  design_mode.read(xml);
  mass_mode.read(xml);
  mass_mode_flops_technology_factor.read(xml);
  common_airfoil_data_path.read(xml);
  vertical_stabilizer.read(xml);
  horizontal_stabilizer.read(xml);
}

}  // namespace low
}  // namespace taw
