# UNICADO - UNIversity Conceptual Aircraft Design and Optimization
#
# Copyright (C) 2025 UNICADO consortium
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <https://www.gnu.org/licenses/>.
#
# Description:
# This file is part of UNICADO.

# Import package libraries.
import os
from numpy import pi
from numpy import sin
from numpy import cos
from numpy import linspace
from numpy import meshgrid
import matplotlib.pyplot as plt


def plot_payload_tubes(project_definition, payload_tube_description,  paths_and_names):
    # Check path to directory for figure outputs
    project_directory = paths_and_names["project_directory"]
    plot_directory = project_directory + '/reporting/plots'
    if not os.path.isdir(plot_directory):
        os.makedirs(plot_directory)

    # Generate figure.
    plot_title = 'Isometric view of fuselage shape'
    fig = plt.figure(figsize=(12, 7.5))
    ax = fig.add_subplot(111, projection='3d')

    # generate cylinder coordinates for each passenger tube
    for tube in range(0, dict_ac_exchange['number_of_payload_tubes']):
        # generate cylinder coordinates for plotting
        z = linspace(round(geometry_dict["tube_center_reference_points"][tube][0] * 2.54 / 100, 3),
                     round(geometry_dict["tube_center_reference_points"][tube][0] * 2.54 / 100, 3)
                     + round(geometry_dict["tube_length"][tube] * 2.54 / 100, 3), 50)
        theta = linspace(0, 2 * pi, 50)
        theta_grid, z_grid = meshgrid(theta, z)
        x_grid = round(geometry_dict["tube_width"][tube] * 2.54 / 100, 3) / 2 * cos(theta_grid) \
            + round(geometry_dict["tube_wall_reference_points"][tube][3][2][1] * 2.54 / 100, 3)
        y_grid = round(geometry_dict["tube_width"][tube] * 2.54 / 100, 3) / 2 * sin(theta_grid) \
            + round(geometry_dict["tube_center_reference_points"][tube][1] * 2.54 / 100, 3)

        # generate surface plot of passenger tube
        ax.plot_surface(y_grid, z_grid, x_grid, alpha=0.3, color='grey')

    ax.set_aspect('equal')
    ax.set_xlabel('passenger tube width in meter', labelpad=15)
    ax.set_ylabel('passenger tube length in meter', labelpad=15)

    # show figure on screen
    plt.show()

    """ Save figures to current aircraft project directory. """
    # Save as *.svg
    tool_name = paths_and_names['tool_name']
    name_of_fig = tool_name + '_' + plot_title + '.svg'
    plt.savefig(plot_directory + '/' + name_of_fig, transparent=True)
    # Save as *.pdf
    name_of_fig = tool_name + '_' + plot_title + '.pdf'
    plt.savefig(plot_directory + '/' + name_of_fig, transparent=True)
