/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#include "TawAnalytical.h"
#include "../../toolinfo.h"
#include <vector>

void TawAnalytical::setHtmlBody() {
    report_.htmlReportStream() << "<div class=\"box data\">\n";
    report_.htmlReportStream() << "<h1>Program Mode: ";
    // Add the plot image to the HTML report
    std::string plotFilePath = rtIO_->getPlotFilesDir() + "/WS_TW_Plot.svg";
    report_.htmlReportStream() << "<div class=\"plot-container\">\n";
    report_.htmlReportStream() << "<img class=\"image-plot\" src=\"" + relativePath(rtIO_->getPlotFilesDir(), rtIO_->getReportDir()) + "/WS_TW_Plot.svg\">" << std::endl;
    report_.htmlReportStream() << "</div>" << std::endl;

    if (data_->configuration.designCase == true) {
        report_.htmlReportStream() << "<h2>Wing loading and Thrust-to-Weight-Ratio</h2>" << std::endl;
        report_.htmlReportStream() << "<table>" << std::endl;
        report_.htmlReportStream() << "<tr><td>Wing Loading (W/S)</td><td>" << Rounding(designWS_, 0) << " kg/m^2</td></tr>" << std::endl;
        report_.htmlReportStream() << "<tr><td>Thrust-to-Weight Ratio (T/W)</td><td>&emsp;" << designTW_ << "</td></tr>" << std::endl;
        report_.htmlReportStream() << "</table>" << std::endl;
        report_.htmlReportStream() << "<h2>Mass Estimation</h2>" << std::endl;
        report_.htmlReportStream() << "<table>" << std::endl;
        report_.htmlReportStream() << "<tr><td>Operating Mass Empty (OME)</td><td>" << Rounding(final_mass_estimation_, 0) << " kg</td></tr>" << std::endl;
        report_.htmlReportStream() << "<tr><td>Maximum Take-Off Mass (MTOM)</td><td>&emsp;" << Rounding(mo_iteration_, 0) << " kg</td></tr>" << std::endl;
        report_.htmlReportStream() << "</table>" << std::endl;
    } else {
        report_.htmlReportStream() << "Study Mode: " << "</h1>" << std::endl;
        report_.htmlReportStream() << "<td>The program was run in study mode.</td>" << std::endl
                                   << "<td>The masses were not redetermined!</td>" << std::endl;
    }  
}


void TawAnalytical::setTexBody() {
    if (data_->configuration.designCase == true) {
        report_.texReportStream() 
            << "\\section{Initial Sizing}" << std::endl
            << "\\begin{frame}" << std::endl
            << " \\frametitle{Initial Sizing ...}" << std::endl
            << "\\begin{figure}" << std::endl
            << "    \\begin{minipage}[b]{0.48\\textwidth}" << std::endl
            << "        \\begin{table}" << std::endl
            << "        \\tiny" << std::endl
            << "        \\begin{tabular}{lcl}" << std::endl
            << "            \\midrule[0.5pt]" << std::endl
            << "            \\multicolumn{3}{l}{Selected Design Point}\\\\"
            << std::endl
            << "            \\midrule[0.5pt]" << std::endl
            << "            \\textcolor{ilrdark}{$\\blacktriangleright$}  Wing Loading & $W/S$ &" << Rounding(designWS_ , 0)<< " $kg/m^{2}$\\\\" << std::endl
            << "            \\textcolor{ilrdark}{$\\blacktriangleright$}  Thrust to Weight & $T/W$ & " << designTW_ << " $-$\\\\" << std::endl
            << "            \\midrule[0.5pt]" << std::endl
            << "            \\multicolumn{3}{l}{Initial Maximum Takeoff Mass}\\\\"
            << std::endl
            << "            \\midrule[0.5pt]" << std::endl
            << "            \\textcolor{ilrdark}{$\\blacktriangleright$}  $MTOM_0$ &  & " << Rounding(mo_iteration_ , 0)<< " $kg$\\\\" << std::endl
            << "        \\end{tabular}" << std::endl
            << "        \\end{table}" << std::endl
            << "    \\end{minipage}" << std::endl
            << "    \\begin{minipage}{0.5\\textwidth}" << std::endl
            << "        \\tiny" << std::endl
            << "        \\def\\svgwidth{5 cm}" << std::endl
            << "        \\import{" + win2lin(relativePath(rtIO_->getPlotDir(), rtIO_->getReportDir())) + "}{" + data_->configuration.theProgramName + "_MassBreakdown_plot.pdf_tex}" << std::endl
            << "        \\caption{\\footnotesize{Initial Sizing Plot}}" << std::endl
            << "    \\end{minipage}" << std::endl
            << "\\end{figure}" << std::endl
            << "\\end{frame}" << std::endl;
    } else {
        report_.texReportStream() 
            << "\\begin{frame}" << std::endl
            << " \\frametitle{Study Mode}" << std::endl
            << std::endl
            << "The program was run in study mode.\\\\" << std::endl
            << "The masses were not redetermined!\\\\" << std::endl
            << "\\end{frame}" << std::endl;
    }
}




