/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 * 
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */
#ifndef PERFORMANCE_ASSESSMENT_SRC_TAW_DEFAULTMETHODS_SARPERFORMANCE_ABSTRACTSARPERFORMANCE_H_
#define PERFORMANCE_ASSESSMENT_SRC_TAW_DEFAULTMETHODS_SARPERFORMANCE_ABSTRACTSARPERFORMANCE_H_

#include <memory>
#include <vector>
#include "../flightEnvelopes/abstractFlightEnvelopes.h"

class abstractSARPerformance {
 public:
    virtual ~abstractSARPerformance() { }

    /**\class dataSARMach class that contains informations about the specific air range
    *
    */
    class dataSARMach {
     public:
        double Altitude; /**< Aircraft altitude (m) */
        std::vector<double> Mach; /**< List of aircraft Mach number (-) */
        std::vector<double> SAR; /**< List of specific air range (m/kg) */

        dataSARMach() {
            Altitude = 0.0;
        }
    };

    /**\class dataSAR class containing data about the optimal performances for the specific air range
    *
    */
    class dataSAR {
     public:
        double Mass; /**< Aircraft mass (kg) */
        double bestSARMach; /**< Mach number for the optimum specific air range (-) */
        double bestSARAlt; /**< Aircraft altitude for the optimum specific air range (m) */
        double bestSAR; /**< Optimum specific air range (m/kg) */
        std::vector<dataSARMach> tabSAR; /**< List of specific air range data */

        dataSAR() {
            Mass = 0.0;
            bestSARMach = 0.0;
            bestSARAlt = 0.0;
            bestSAR = 0.0;
        }
    };
    std::vector<dataSAR> theSAR; /**< List of temporarily specific air range at the i mission segment */


    virtual void doSARCalculation(std::shared_ptr<abstractFlightEnvelopes> aFlightEnvelopes) = 0;
};

#endif  // PERFORMANCE_ASSESSMENT_SRC_TAW_DEFAULTMETHODS_SARPERFORMANCE_ABSTRACTSARPERFORMANCE_H_
