/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#ifndef SYSTEMS_DESIGN_SRC_AIRCRAFTSYSTEMS_CONVENTIONALATA26_H_
#define SYSTEMS_DESIGN_SRC_AIRCRAFTSYSTEMS_CONVENTIONALATA26_H_

/* The following statements import necessary libraries */
#include <string>                                                   // Import c++ standard library for using string
#include <vector>                                                   // Import c++ standard library for using vector
#include <memory>

/* The following statements import necessary header files */
#include "../aircraftSystem.h"                                      // Import of header file from src folder for aircraftSystem
#include "../powerProfile.h"                                        // Import of header file from src folder for powerProfile
#include <svl/SVL.h>                                                // Import of header file from src folder for SVL
#include "../systemsIOData.h"                                       // Import of header file from systemsIOData for accessing data_. Can't be included in
                                                                    // aircraftSystem.h because that would lead to circular dependencies
#include <aircraftGeometry2/processing/measure.h>

/** \class conventionalATA26
 * \brief Contains all properties of the fire protection system (ATA26)
 */
class conventionalATA26: public aircraftSystem {
 public:
    /**
     * \brief function for reading the system specific parameters from the config
     * 
     * \param config const node&: systemsDesign configuration file
    */
    void readParameters(const node& config) override;
    /**
     * \brief function for updating the system specific values in the aircraft xml
    */
    void updateXML() override;
    void calculateSystemsPower(const powerProfile& allPreviousSystemsBleed,
                               const std::vector<powerProfile>& allPreviousSystemsHydraulic,
                               const std::vector<powerProfile>& allPreviousSystemsElectric,
                               const powerProfile& allPreviousSystemsHeat) override;
    void calculateSinkMass(const powerProfile& sourceBleed,
                           const std::vector<powerProfile>& sourceElectric,
                           const std::vector<powerProfile>& sourceHydraulic) override;
    void getPower();

    double getMass();
    Vec3 getRefPoint();

    conventionalATA26(const std::string& systemName, bool systemIsOperating, std::shared_ptr<systemsIOData> data, const RuntimeIO& rtIO);
    virtual ~conventionalATA26();
};

#endif // SYSTEMS_DESIGN_SRC_AIRCRAFTSYSTEMS_CONVENTIONALATA26_H_
