# UNICADO - UNIversity Conceptual Aircraft Design and Optimization
#
# Copyright (C) 2025 UNICADO consortium
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <https://www.gnu.org/licenses/>.
#
# Description:
# This file is part of UNICADO.

def calculate_center_of_gravity(tank_shape, diameter_front, diameter_rear, length):
    """_summary_

    :param _type_ tank_entity: _description_
    :param dict dict_ac_data: Dict containing parameter and values from aircraft exchange and module configuration file
    :param dict dict_tank_design: Dict containing results from tank design
    :param logging.Logger runtime_output: Logging object used for capturing log messages in the module
    """

    match tank_shape:
        case 'conical':
            x_coordinate_center_of_gravity = length/3 * (diameter_front + 2*diameter_rear)/(diameter_front
                                                                                            + diameter_rear)
            z_coordinate_center_of_gravity = (diameter_front**2 - diameter_rear**2
                                              + abs(diameter_rear)*(diameter_front + 2*diameter_rear))/(
                                                  3*(diameter_front + diameter_rear))
            print('Calculating center of gravity for conical tank.')

        case 'cylindrical':
            x_coordinate_center_of_gravity = length/2
            z_coordinate_center_of_gravity = diameter_front/2
            print('Calculating center of gravity for cylindrical tank.')

    y_coordinate_center_of_gravity = 0.0

    return x_coordinate_center_of_gravity, y_coordinate_center_of_gravity, z_coordinate_center_of_gravity
