/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#include "aspectRatioMethods.h"

#include <cmath>
#include <functional>
#include <iostream>
#include <map>

double user_defined::aspect_ratio(const double user_aspect_ratio) { return user_aspect_ratio; }

double by_pitch_up_limit_function::aspect_ratio(const double sweep_at_quarter_chord) {
  return -8.5 * log(sweep_at_quarter_chord) + 5.875;  // empirical function
}

double get_design_aspect_ratio(modes aspect_ratio_mode, const double user_aspect_ratio,
                               const double quarter_chord_sweep) {
  std::map<modes, std::tuple<std::string, std::function<double(void)>>> aspect_ratio_selection = {
      {"mode_0", {"user_defined", [=]() { return user_defined::aspect_ratio(user_aspect_ratio); }}},
      {"mode_1", {"by_pitch_up_limit_function", [=]() {
                    return by_pitch_up_limit_function::aspect_ratio(quarter_chord_sweep);
                  }}}};
  const auto [method, aspect_ratio_method] = aspect_ratio_selection[aspect_ratio_mode];
  double aspect_ratio = aspect_ratio_method();
  std::cout << "Wing aspect ratio [method]: " << method << "\n";
  std::cout << "Wing aspect ratio  [value]: " << aspect_ratio << " [1]\n";
  return aspect_ratio;
}