/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#ifndef CONTROL_DEVICE_METHODS
#define CONTROL_DEVICE_METHODS

#include <aircraftGeometry2/geometry/surface.h>

#include <iostream>
#include <tuple>

#include "lib/io_methods/controlDeviceIO.h"
using modes = std::string;

namespace user_defined {
std::tuple<std::vector<geom2::MultisectionSurface<geom2::PolygonSection>>, std::vector<std::tuple<double, double>>>
control_devices(std::vector<ControlDevice> devices);
}  // namespace user_defined

namespace empirical {
std::tuple<std::vector<geom2::MultisectionSurface<geom2::PolygonSection>>, std::vector<std::tuple<double, double>>>
control_devices(const std::vector<geom2::MultisectionSurface<geom2::PolygonSection>>& spars,
                const geom2::MultisectionSurface<geom2::AirfoilSection>& wing,
                const geom2::MultisectionSurface<geom2::PolygonSection>& fuselage, const bool is_kinked,
                const double eta_kink, const std::string& config_leading_edge_high_lift_device_type,
                const std::string& config_trailing_edge_high_lift_device_type);
}  // namespace empirical

std::tuple<std::vector<geom2::MultisectionSurface<geom2::PolygonSection>>, std::vector<std::tuple<double, double>>>
get_control_devices(modes control_device_mode, std::vector<ControlDevice> devices,
                    const std::vector<geom2::MultisectionSurface<geom2::PolygonSection>>& spars,
                    const geom2::MultisectionSurface<geom2::AirfoilSection>& wing,
                    const geom2::MultisectionSurface<geom2::PolygonSection>& fuselage, const bool is_kinked,
                    const double eta_kink, const std::string& config_leading_edge_high_lift_device_type,
                    const std::string& config_trailing_edge_high_lift_device_type);

#endif  // CONTROL_DEVICE_METHODS