/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#include "taperRatioMethods.h"

#include <functional>
#include <iostream>
#include <map>

double user_defined::taper_ratio(const double user_taper_ratio) { return user_taper_ratio; }

double howe::taper_ratio(const double aspect_ratio, const double quarter_chord_sweep) {
  return .2 * pow(aspect_ratio, 0.25) * pow(cos(quarter_chord_sweep), 2.0);
}

double get_design_taper_ratio(modes taper_ratio_mode, const double user_taper_ratio, const double aspect_ratio,
                              const double quarter_chord_sweep) {
  std::map<modes, std::tuple<std::string, std::function<double(void)>>> taper_ratio_selection = {
      {"mode_0", {"user_defined", [=]() { return user_defined::taper_ratio(user_taper_ratio); }}},
      {"mode_1", {"howe", [=]() { return howe::taper_ratio(aspect_ratio, quarter_chord_sweep); }}}};
  const auto [method, taper_ratio_method] = taper_ratio_selection[taper_ratio_mode];
  double taper_ratio = taper_ratio_method();
  std::cout << "Wing taper ratio [method]: " << method << "\n";
  std::cout << "Wing taper ratio  [value]: " << taper_ratio << " [1]\n";
  return taper_ratio;
}