/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#ifndef BISECTION_METHOD_H_
#define BISECTION_METHOD_H_

#include <cmath>
#include <exception>
#include <functional>

double bisection_algorithm(const std::function<double(double)> &fun, double start_left, double start_right,
                           double end_condition);

double bisection_algorithm(const std::function<double(double)> &fun, double start_left, double start_right,
                           double end_condition = 1E-10) {
  double intermediate, left = start_left, right = start_right;
  constexpr int max_iteration = 400;
  int iteration = 0;
  double to_check = 0;
  double value_left, value_right;
  do {
    value_left = fun(left);
    value_right = fun(right);
    to_check = value_left * value_right;
    if (to_check < 0.0) {
      intermediate = 0.5 * (left + right);
      if (fun(left) * fun(intermediate) < 0) {
        right = intermediate;
      } else {
        left = intermediate;
      }
    } else {
      if (abs(value_left) < 1E-20) {
        return left;
      } else if (abs(value_right) < 1E-20) {
        return right;
      } else {
        throw("Bad condition for bisection method f(l)*f(r) >= 0 -> change bounds");
      }
    }
  } while ((abs(right - left) > 1E-20) && ((abs(value_left) > 1E-10) || (abs(value_right) > 1E-10)) &&
           (iteration < max_iteration));
  return right;
}

#endif  // BISECTION_METHOD_H_