/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */


#ifndef NEWTON_ALGORITHM_H_
#define NEWTON_ALGORITHM_H_

#include <functional>
#include <iostream>
#include <limits>

double newton_algorithm(auto& fun, double x0) {
  double fx, fxh, fx_;
  double x = x0;
  constexpr double h = 0.001;
  do {
    fx = fun(x);
    fxh = fun(x + h);
    fx_ = (fxh - fx) / h;
    x -= fx / fx_;
  } while (abs(fx) > 1e-10 && abs(fx - fxh) > 1e-13);

  return x;
}

double newton_algorithm(auto& fun, auto& fun_, double x0) {
  double fx, fx_, x = x0;
  do {
    fx = fun(x);
    fx_ = fun_(x);
    x -= fx / fx_;
  } while (abs(fx) > 1e-10);

  return x;
}

#endif  // NEWTON_ALGORITHM_H_